@@ -1,4 +1,4 @@
-from pyrogram import InlineKeyboardMarkup
+from pyrogram.types import InlineKeyboardMarkup
 
 
 class InlineKeyboard(InlineKeyboardMarkup):
